Index: views/widget/widget_delegate.h |
diff --git a/views/widget/widget_delegate.h b/views/widget/widget_delegate.h |
index 85485e6204452fa8c5e22a4af7b6e728e15928db..5c73d4dcfef4649c0ade629f83ebbaf99d45dd65 100644 |
--- a/views/widget/widget_delegate.h |
+++ b/views/widget/widget_delegate.h |
@@ -10,6 +10,7 @@ |
#include "base/memory/scoped_ptr.h" |
#include "ui/base/accessibility/accessibility_types.h" |
+#include "ui/base/ui_base_types.h" |
#include "views/view.h" |
class SkBitmap; |
@@ -97,15 +98,16 @@ class VIEWS_EXPORT WidgetDelegate { |
// state restoration. |
virtual std::wstring GetWindowName() const; |
// Saves the window's bounds and maximized states. By default this uses the |
// process' local state keyed by window name (See GetWindowName above). This |
// behavior can be overridden to provide additional functionality. |
- virtual void SaveWindowPlacement(const gfx::Rect& bounds, bool maximized); |
+ virtual void SaveWindowPlacement(const gfx::Rect& bounds, |
+ ui::WindowShowState show_state); |
- // Retrieves the window's bounds and maximized states. |
+ // Retrieves the window's bounds and "show" states. |
// This behavior can be overridden to provide additional functionality. |
- virtual bool GetSavedWindowBounds(gfx::Rect* bounds) const; |
- virtual bool GetSavedMaximizedState(bool* maximized) const; |
+ virtual bool GetSavedWindowPlacement(gfx::Rect* bounds, |
+ ui::WindowShowState* show_state) const; |
// Returns true if the window's size should be restored. If this is false, |
// only the window's origin is restored and the window is given its |
@@ -97,15 +98,16 @@ class VIEWS_EXPORT WidgetDelegate { |
// state restoration. |
virtual std::wstring GetWindowName() const; |
- // Saves the window's bounds and maximized states. By default this uses the |
+ // Saves the window's bounds and "show" state. By default this uses the |
// process' local state keyed by window name (See GetWindowName above). This |
// behavior can be overridden to provide additional functionality. |